/**
 * File: lex-test.cpp
 * ------------------
 * Provides a simple test framework that allows
 * us to confirm our Lex class works as expected.
 */

#include <iostream>
#include <fstream>
#include <string>
#include "console.h"
#include "lex.h"
#include "simpio.h"
using namespace std;

/**
 * Function: loadWordsFromFile
 * ---------------------------
 * Accepts an empty Lexicon and the name of a flat text file that
 * contains a series of words, one per line.  loadWordsFromFile
 * then reads all of the words from the file with the supplied name
 * and inserts them into the lexicon.
 */
static void loadWordsFromFile(Lex& lexicon, const string& filename) {
    ifstream infile(filename);
    if (infile.fail()) error("\"" + filename + "\" could not be found.");
    
    while (true) {
        string word;
        getline(infile, word);
        if (infile.fail()) return;
        lexicon.add(word);
    }
}

/**
 * Function: testLexicon
 * ---------------------
 * Provides a trivial, interactive framework that allows the user
 * to exercise the Lex class.
 */
static void testLexicon(const Lex& lexicon) {
    while (true) {
        string response = getLine("Enter a word [or hit return to quit]: ");
        if (response.empty()) break;
        if (lexicon.contains(response)) {
            cout << "\"" << response << "\" is a word." << endl;
        } else if (lexicon.containsPrefix(response)) {
            cout << "\"" << response << "\" isn't a word, but it's "
                 << "a prefix of one or more words." << endl;
        } else {
            cout << "\"" << response << "\" is neither a word nor "
                 << "a prefix of some word." << endl;
        }
    }
    cout << "All done!" << endl;
}

/**
 * Function: main
 * --------------
 * Defines the entry point for the entire test program.
 */
int main() {
    Lex lexicon;
    loadWordsFromFile(lexicon, "words.txt");
    testLexicon(lexicon);
    return 0;
}
